==> VoiceOver-1.0.1.tar.bz2: VoiceOver-1.0.1/voxd.h <==
/*
** voxd.h - Internal constants, structures, and function definitions for the voxd VoiceOver daemon
** Copyright (C) 2017  Lew Pitcher
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License along
** with this program; if not, write to the Free Software Foundation, Inc.,
** 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**
** Lew Pitcher <lew.pitcher@digitalfreehold.ca>
*/

struct show {
  struct role	*roles;
  struct actor	*actors;
  char		*prologue,
		*epilogue;
};

struct actor {
  struct actor	*actorNext;
  char		*actorName;
  char		*voicePath;
  float		voiceTempo,
		voicePitch,
		voiceIntonation;
};
 
struct role {
  struct role	*roleNext;
  char		*roleName;
  struct actor	*roleActor;
};

/*
** OpenShow()	Construct VoiceOver configuration tree
** Accepts:	pointer to character string naming configuration file path
** Process:	read config file to build config tree
** Returns:	pointer to the root of config tree, or NULL on failure
*/
struct show *OpenShow(char *);

/*
** CloseShow()	Demolish VoiceOver configuration tree
** Accepts:	pointer to the root of config tree
** Process:	release all storage allocated to the tree
** Returns:	nothing
*/
void CloseShow(struct show *);

/*
** GetActorInRole	Retrieve voice particulars for a specified role
** Accepts:	pointer to character string naming the role to retrieve
**		pointer to struct show of root of config tree
** Process:	look through config tree for role
**		if found, return the actor for that role
**		otherwise, return the actor that voices for STANDIN
** Returns:	pointer to struct actor of the voice for the specified role
*/
struct actor *GetActorInRole(char *, struct show *);

#define	STANDIN_ROLE	"STANDIN"
#define STANDIN_ACTOR	"--standin--"
#define STANDIN_VOICE	"rms"

==> VoiceOver-1.0.5.tar.bz2: VoiceOver-1.0.5/voxd.h <==
/*
** voxd.h - Internal constants, structures, and function definitions for the voxd VoiceOver daemon
** Copyright (C) 2017, 2020  Lew Pitcher
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License along
** with this program; if not, write to the Free Software Foundation, Inc.,
** 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
**
** Lew Pitcher <lew.pitcher@digitalfreehold.ca>
*/

struct show {
  struct role	*roles;
  struct actor	*actors;
  char		*prologue,
		*epilogue,
		*refresh;
};

struct actor {
  struct actor	*actorNext;
  char		*actorName;
  char		*voicePath;
  float		voiceTempo,
		voicePitch,
		voiceIntonation;
};
 
struct role {
  struct role	*roleNext;
  char		*roleName;
  struct actor	*roleActor;
};

/*
** OpenShow()	Construct VoiceOver configuration tree
** Accepts:	pointer to character string naming configuration file path
** Process:	read config file to build config tree
** Returns:	pointer to the root of config tree, or NULL on failure
*/
struct show *OpenShow(char *);

/*
** CloseShow()	Demolish VoiceOver configuration tree
** Accepts:	pointer to the root of config tree
** Process:	release all storage allocated to the tree
** Returns:	nothing
*/
void CloseShow(struct show *);

/*
** WriteShow()	Externalize VoiceOver configuration tree
** Accepts:	FILE pointer to open stdio file,
**		pointer to the root of the config tree
** Process:	writes textual representation of VoiceOver
**		configuration tree to specified file
** Returns:	nothing
*/
void WriteShow(FILE *, struct show *);

/*
** GetActorInRole	Retrieve voice particulars for a specified role
** Accepts:	pointer to character string naming the role to retrieve
**		pointer to struct show of root of config tree
** Process:	look through config tree for role
**		if found, return the actor for that role
**		otherwise, return the actor that voices for CHORUS
** Returns:	pointer to struct actor of the voice for the specified role
*/
struct actor *GetActorInRole(char *, struct show *);

/*
** The CHORUS_ROLE speaks the prologue/epilogue/refresh speeches,
** and any lines specified for roles missing from the
** VoiceOver configuration tree.
**
** The following constants define the characteristics of a
** default CHORUS_ROLE, should one not be specified in the
** configuration.
*/
#define	CHORUS_ROLE	"CHORUS"
#define CHORUS_ACTOR	"--chorus--"
#define CHORUS_VOICE	"rms"
